@@ -25,40 +25,40 @@ from color_matcher.mvgd_matcher import TransferMVGD
 from color_matcher.reinhard_matcher import ReinhardMatcher
 import numpy as np
 
-METHODS = ('default', 'mvgd', 'hm', 'hm-mkl-hm', 'reinhard')
+METHODS = ('default', 'hm', 'reinhard', 'mvgd', 'mkl', 'hm-mvgd-hm', 'hm-mkl-hm')
 
 
-class ColorMatcher(HistogramMatcher, TransferMVGD, ReinhardMatcher):
+class ColorMatcher(HistogramMatcher, ReinhardMatcher, TransferMVGD):
 
     def __init__(self, *args, **kwargs):
         super(ColorMatcher, self).__init__(*args, **kwargs)
 
         self._method = kwargs['method'] if 'method' in kwargs else 'default'
 
-    def main(self, method: str=None) -> np.ndarray:
+    def main(self, method: str = None) -> np.ndarray:
         """
-        The main function and high-level entry point performing the mapping. Valid methods are
+        The main function is the high-level entry point performing the mapping. Valid methods are:
 
-        :param method: ('default', 'mvgd', 'hm', 'hm-mkl-hm', 'reinhard') describing how to conduct color mapping
+        :param method: ('default', 'hm', 'reinhard', 'mvgd', 'mkl', 'hm-mvgd-hm', 'hm-mkl-hm') determining color mapping
         :type method: :class:`str`
 
         :return: Resulting image after color mapping
         :rtype: np.ndarray
         """
 
-        self._method = self._method if method is None else method
+        self._method = self._method.lower() if method is None else method.lower()
 
         # color transfer methods (to be iterated through)
         if self._method == METHODS[0]:
             funs = [self.transfer]
         elif self._method == METHODS[1]:
-            funs = [self.transfer]
-        elif self._method == METHODS[2]:
             funs = [self.hist_match]
-        elif self._method == METHODS[3]:
-            funs = [self.hist_match, self.transfer, self.hist_match]
-        elif self._method == METHODS[4]:
+        elif self._method == METHODS[2]:
             funs = [self.reinhard]
+        elif self._method in METHODS[3:5]:
+            funs = [self.transfer]
+        elif self._method in METHODS[5:]:
+            funs = [self.hist_match, self.transfer, self.hist_match]
         else:
             raise BaseException('Method type \'%s\' not recognized' % method)
 
